/*******************************************************************************
* File Name: GP3.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_GP3_H) /* Pins GP3_H */
#define CY_PINS_GP3_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "GP3_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 GP3__PORT == 15 && ((GP3__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    GP3_Write(uint8 value);
void    GP3_SetDriveMode(uint8 mode);
uint8   GP3_ReadDataReg(void);
uint8   GP3_Read(void);
void    GP3_SetInterruptMode(uint16 position, uint16 mode);
uint8   GP3_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the GP3_SetDriveMode() function.
     *  @{
     */
        #define GP3_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define GP3_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define GP3_DM_RES_UP          PIN_DM_RES_UP
        #define GP3_DM_RES_DWN         PIN_DM_RES_DWN
        #define GP3_DM_OD_LO           PIN_DM_OD_LO
        #define GP3_DM_OD_HI           PIN_DM_OD_HI
        #define GP3_DM_STRONG          PIN_DM_STRONG
        #define GP3_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define GP3_MASK               GP3__MASK
#define GP3_SHIFT              GP3__SHIFT
#define GP3_WIDTH              8u

/* Interrupt constants */
#if defined(GP3__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in GP3_SetInterruptMode() function.
     *  @{
     */
        #define GP3_INTR_NONE      (uint16)(0x0000u)
        #define GP3_INTR_RISING    (uint16)(0x0001u)
        #define GP3_INTR_FALLING   (uint16)(0x0002u)
        #define GP3_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define GP3_INTR_MASK      (0x01u) 
#endif /* (GP3__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define GP3_PS                     (* (reg8 *) GP3__PS)
/* Data Register */
#define GP3_DR                     (* (reg8 *) GP3__DR)
/* Port Number */
#define GP3_PRT_NUM                (* (reg8 *) GP3__PRT) 
/* Connect to Analog Globals */                                                  
#define GP3_AG                     (* (reg8 *) GP3__AG)                       
/* Analog MUX bux enable */
#define GP3_AMUX                   (* (reg8 *) GP3__AMUX) 
/* Bidirectional Enable */                                                        
#define GP3_BIE                    (* (reg8 *) GP3__BIE)
/* Bit-mask for Aliased Register Access */
#define GP3_BIT_MASK               (* (reg8 *) GP3__BIT_MASK)
/* Bypass Enable */
#define GP3_BYP                    (* (reg8 *) GP3__BYP)
/* Port wide control signals */                                                   
#define GP3_CTL                    (* (reg8 *) GP3__CTL)
/* Drive Modes */
#define GP3_DM0                    (* (reg8 *) GP3__DM0) 
#define GP3_DM1                    (* (reg8 *) GP3__DM1)
#define GP3_DM2                    (* (reg8 *) GP3__DM2) 
/* Input Buffer Disable Override */
#define GP3_INP_DIS                (* (reg8 *) GP3__INP_DIS)
/* LCD Common or Segment Drive */
#define GP3_LCD_COM_SEG            (* (reg8 *) GP3__LCD_COM_SEG)
/* Enable Segment LCD */
#define GP3_LCD_EN                 (* (reg8 *) GP3__LCD_EN)
/* Slew Rate Control */
#define GP3_SLW                    (* (reg8 *) GP3__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define GP3_PRTDSI__CAPS_SEL       (* (reg8 *) GP3__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define GP3_PRTDSI__DBL_SYNC_IN    (* (reg8 *) GP3__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define GP3_PRTDSI__OE_SEL0        (* (reg8 *) GP3__PRTDSI__OE_SEL0) 
#define GP3_PRTDSI__OE_SEL1        (* (reg8 *) GP3__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define GP3_PRTDSI__OUT_SEL0       (* (reg8 *) GP3__PRTDSI__OUT_SEL0) 
#define GP3_PRTDSI__OUT_SEL1       (* (reg8 *) GP3__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define GP3_PRTDSI__SYNC_OUT       (* (reg8 *) GP3__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(GP3__SIO_CFG)
    #define GP3_SIO_HYST_EN        (* (reg8 *) GP3__SIO_HYST_EN)
    #define GP3_SIO_REG_HIFREQ     (* (reg8 *) GP3__SIO_REG_HIFREQ)
    #define GP3_SIO_CFG            (* (reg8 *) GP3__SIO_CFG)
    #define GP3_SIO_DIFF           (* (reg8 *) GP3__SIO_DIFF)
#endif /* (GP3__SIO_CFG) */

/* Interrupt Registers */
#if defined(GP3__INTSTAT)
    #define GP3_INTSTAT            (* (reg8 *) GP3__INTSTAT)
    #define GP3_SNAP               (* (reg8 *) GP3__SNAP)
    
	#define GP3_0_INTTYPE_REG 		(* (reg8 *) GP3__0__INTTYPE)
	#define GP3_1_INTTYPE_REG 		(* (reg8 *) GP3__1__INTTYPE)
	#define GP3_2_INTTYPE_REG 		(* (reg8 *) GP3__2__INTTYPE)
	#define GP3_3_INTTYPE_REG 		(* (reg8 *) GP3__3__INTTYPE)
	#define GP3_4_INTTYPE_REG 		(* (reg8 *) GP3__4__INTTYPE)
	#define GP3_5_INTTYPE_REG 		(* (reg8 *) GP3__5__INTTYPE)
	#define GP3_6_INTTYPE_REG 		(* (reg8 *) GP3__6__INTTYPE)
	#define GP3_7_INTTYPE_REG 		(* (reg8 *) GP3__7__INTTYPE)
#endif /* (GP3__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_GP3_H */


/* [] END OF FILE */
