/*******************************************************************************
* File Name: IORQn.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_IORQn_H) /* Pins IORQn_H */
#define CY_PINS_IORQn_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "IORQn_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 IORQn__PORT == 15 && ((IORQn__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    IORQn_Write(uint8 value);
void    IORQn_SetDriveMode(uint8 mode);
uint8   IORQn_ReadDataReg(void);
uint8   IORQn_Read(void);
void    IORQn_SetInterruptMode(uint16 position, uint16 mode);
uint8   IORQn_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the IORQn_SetDriveMode() function.
     *  @{
     */
        #define IORQn_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define IORQn_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define IORQn_DM_RES_UP          PIN_DM_RES_UP
        #define IORQn_DM_RES_DWN         PIN_DM_RES_DWN
        #define IORQn_DM_OD_LO           PIN_DM_OD_LO
        #define IORQn_DM_OD_HI           PIN_DM_OD_HI
        #define IORQn_DM_STRONG          PIN_DM_STRONG
        #define IORQn_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define IORQn_MASK               IORQn__MASK
#define IORQn_SHIFT              IORQn__SHIFT
#define IORQn_WIDTH              1u

/* Interrupt constants */
#if defined(IORQn__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in IORQn_SetInterruptMode() function.
     *  @{
     */
        #define IORQn_INTR_NONE      (uint16)(0x0000u)
        #define IORQn_INTR_RISING    (uint16)(0x0001u)
        #define IORQn_INTR_FALLING   (uint16)(0x0002u)
        #define IORQn_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define IORQn_INTR_MASK      (0x01u) 
#endif /* (IORQn__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define IORQn_PS                     (* (reg8 *) IORQn__PS)
/* Data Register */
#define IORQn_DR                     (* (reg8 *) IORQn__DR)
/* Port Number */
#define IORQn_PRT_NUM                (* (reg8 *) IORQn__PRT) 
/* Connect to Analog Globals */                                                  
#define IORQn_AG                     (* (reg8 *) IORQn__AG)                       
/* Analog MUX bux enable */
#define IORQn_AMUX                   (* (reg8 *) IORQn__AMUX) 
/* Bidirectional Enable */                                                        
#define IORQn_BIE                    (* (reg8 *) IORQn__BIE)
/* Bit-mask for Aliased Register Access */
#define IORQn_BIT_MASK               (* (reg8 *) IORQn__BIT_MASK)
/* Bypass Enable */
#define IORQn_BYP                    (* (reg8 *) IORQn__BYP)
/* Port wide control signals */                                                   
#define IORQn_CTL                    (* (reg8 *) IORQn__CTL)
/* Drive Modes */
#define IORQn_DM0                    (* (reg8 *) IORQn__DM0) 
#define IORQn_DM1                    (* (reg8 *) IORQn__DM1)
#define IORQn_DM2                    (* (reg8 *) IORQn__DM2) 
/* Input Buffer Disable Override */
#define IORQn_INP_DIS                (* (reg8 *) IORQn__INP_DIS)
/* LCD Common or Segment Drive */
#define IORQn_LCD_COM_SEG            (* (reg8 *) IORQn__LCD_COM_SEG)
/* Enable Segment LCD */
#define IORQn_LCD_EN                 (* (reg8 *) IORQn__LCD_EN)
/* Slew Rate Control */
#define IORQn_SLW                    (* (reg8 *) IORQn__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define IORQn_PRTDSI__CAPS_SEL       (* (reg8 *) IORQn__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define IORQn_PRTDSI__DBL_SYNC_IN    (* (reg8 *) IORQn__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define IORQn_PRTDSI__OE_SEL0        (* (reg8 *) IORQn__PRTDSI__OE_SEL0) 
#define IORQn_PRTDSI__OE_SEL1        (* (reg8 *) IORQn__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define IORQn_PRTDSI__OUT_SEL0       (* (reg8 *) IORQn__PRTDSI__OUT_SEL0) 
#define IORQn_PRTDSI__OUT_SEL1       (* (reg8 *) IORQn__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define IORQn_PRTDSI__SYNC_OUT       (* (reg8 *) IORQn__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(IORQn__SIO_CFG)
    #define IORQn_SIO_HYST_EN        (* (reg8 *) IORQn__SIO_HYST_EN)
    #define IORQn_SIO_REG_HIFREQ     (* (reg8 *) IORQn__SIO_REG_HIFREQ)
    #define IORQn_SIO_CFG            (* (reg8 *) IORQn__SIO_CFG)
    #define IORQn_SIO_DIFF           (* (reg8 *) IORQn__SIO_DIFF)
#endif /* (IORQn__SIO_CFG) */

/* Interrupt Registers */
#if defined(IORQn__INTSTAT)
    #define IORQn_INTSTAT            (* (reg8 *) IORQn__INTSTAT)
    #define IORQn_SNAP               (* (reg8 *) IORQn__SNAP)
    
	#define IORQn_0_INTTYPE_REG 		(* (reg8 *) IORQn__0__INTTYPE)
#endif /* (IORQn__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_IORQn_H */


/* [] END OF FILE */
