/*******************************************************************************
* File Name: Kbd0_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "Kbd0.h"

/* Check for removal by optimization */
#if !defined(Kbd0_Sync_ctrl_reg__REMOVED)

static Kbd0_BACKUP_STRUCT  Kbd0_backup = {0u};

    
/*******************************************************************************
* Function Name: Kbd0_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Kbd0_SaveConfig(void) 
{
    Kbd0_backup.controlState = Kbd0_Control;
}


/*******************************************************************************
* Function Name: Kbd0_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void Kbd0_RestoreConfig(void) 
{
     Kbd0_Control = Kbd0_backup.controlState;
}


/*******************************************************************************
* Function Name: Kbd0_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Kbd0_Sleep(void) 
{
    Kbd0_SaveConfig();
}


/*******************************************************************************
* Function Name: Kbd0_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Kbd0_Wakeup(void)  
{
    Kbd0_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
