/*******************************************************************************
* File Name: Kbd6_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "Kbd6.h"

/* Check for removal by optimization */
#if !defined(Kbd6_Sync_ctrl_reg__REMOVED)

static Kbd6_BACKUP_STRUCT  Kbd6_backup = {0u};

    
/*******************************************************************************
* Function Name: Kbd6_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Kbd6_SaveConfig(void) 
{
    Kbd6_backup.controlState = Kbd6_Control;
}


/*******************************************************************************
* Function Name: Kbd6_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void Kbd6_RestoreConfig(void) 
{
     Kbd6_Control = Kbd6_backup.controlState;
}


/*******************************************************************************
* Function Name: Kbd6_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Kbd6_Sleep(void) 
{
    Kbd6_SaveConfig();
}


/*******************************************************************************
* Function Name: Kbd6_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Kbd6_Wakeup(void)  
{
    Kbd6_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
