/*******************************************************************************
* File Name: Kbd7_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "Kbd7.h"

/* Check for removal by optimization */
#if !defined(Kbd7_Sync_ctrl_reg__REMOVED)

static Kbd7_BACKUP_STRUCT  Kbd7_backup = {0u};

    
/*******************************************************************************
* Function Name: Kbd7_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Kbd7_SaveConfig(void) 
{
    Kbd7_backup.controlState = Kbd7_Control;
}


/*******************************************************************************
* Function Name: Kbd7_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void Kbd7_RestoreConfig(void) 
{
     Kbd7_Control = Kbd7_backup.controlState;
}


/*******************************************************************************
* Function Name: Kbd7_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Kbd7_Sleep(void) 
{
    Kbd7_SaveConfig();
}


/*******************************************************************************
* Function Name: Kbd7_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Kbd7_Wakeup(void)  
{
    Kbd7_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
