/*******************************************************************************
* File Name: zx81_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "zx81.h"

/* Check for removal by optimization */
#if !defined(zx81_Sync_ctrl_reg__REMOVED)

static zx81_BACKUP_STRUCT  zx81_backup = {0u};

    
/*******************************************************************************
* Function Name: zx81_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void zx81_SaveConfig(void) 
{
    zx81_backup.controlState = zx81_Control;
}


/*******************************************************************************
* Function Name: zx81_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void zx81_RestoreConfig(void) 
{
     zx81_Control = zx81_backup.controlState;
}


/*******************************************************************************
* Function Name: zx81_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void zx81_Sleep(void) 
{
    zx81_SaveConfig();
}


/*******************************************************************************
* Function Name: zx81_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void zx81_Wakeup(void)  
{
    zx81_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
