/*******************************************************************************
* File Name: GP38.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_GP38_H) /* Pins GP38_H */
#define CY_PINS_GP38_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "GP38_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 GP38__PORT == 15 && ((GP38__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    GP38_Write(uint8 value);
void    GP38_SetDriveMode(uint8 mode);
uint8   GP38_ReadDataReg(void);
uint8   GP38_Read(void);
void    GP38_SetInterruptMode(uint16 position, uint16 mode);
uint8   GP38_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the GP38_SetDriveMode() function.
     *  @{
     */
        #define GP38_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define GP38_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define GP38_DM_RES_UP          PIN_DM_RES_UP
        #define GP38_DM_RES_DWN         PIN_DM_RES_DWN
        #define GP38_DM_OD_LO           PIN_DM_OD_LO
        #define GP38_DM_OD_HI           PIN_DM_OD_HI
        #define GP38_DM_STRONG          PIN_DM_STRONG
        #define GP38_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define GP38_MASK               GP38__MASK
#define GP38_SHIFT              GP38__SHIFT
#define GP38_WIDTH              1u

/* Interrupt constants */
#if defined(GP38__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in GP38_SetInterruptMode() function.
     *  @{
     */
        #define GP38_INTR_NONE      (uint16)(0x0000u)
        #define GP38_INTR_RISING    (uint16)(0x0001u)
        #define GP38_INTR_FALLING   (uint16)(0x0002u)
        #define GP38_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define GP38_INTR_MASK      (0x01u) 
#endif /* (GP38__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define GP38_PS                     (* (reg8 *) GP38__PS)
/* Data Register */
#define GP38_DR                     (* (reg8 *) GP38__DR)
/* Port Number */
#define GP38_PRT_NUM                (* (reg8 *) GP38__PRT) 
/* Connect to Analog Globals */                                                  
#define GP38_AG                     (* (reg8 *) GP38__AG)                       
/* Analog MUX bux enable */
#define GP38_AMUX                   (* (reg8 *) GP38__AMUX) 
/* Bidirectional Enable */                                                        
#define GP38_BIE                    (* (reg8 *) GP38__BIE)
/* Bit-mask for Aliased Register Access */
#define GP38_BIT_MASK               (* (reg8 *) GP38__BIT_MASK)
/* Bypass Enable */
#define GP38_BYP                    (* (reg8 *) GP38__BYP)
/* Port wide control signals */                                                   
#define GP38_CTL                    (* (reg8 *) GP38__CTL)
/* Drive Modes */
#define GP38_DM0                    (* (reg8 *) GP38__DM0) 
#define GP38_DM1                    (* (reg8 *) GP38__DM1)
#define GP38_DM2                    (* (reg8 *) GP38__DM2) 
/* Input Buffer Disable Override */
#define GP38_INP_DIS                (* (reg8 *) GP38__INP_DIS)
/* LCD Common or Segment Drive */
#define GP38_LCD_COM_SEG            (* (reg8 *) GP38__LCD_COM_SEG)
/* Enable Segment LCD */
#define GP38_LCD_EN                 (* (reg8 *) GP38__LCD_EN)
/* Slew Rate Control */
#define GP38_SLW                    (* (reg8 *) GP38__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define GP38_PRTDSI__CAPS_SEL       (* (reg8 *) GP38__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define GP38_PRTDSI__DBL_SYNC_IN    (* (reg8 *) GP38__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define GP38_PRTDSI__OE_SEL0        (* (reg8 *) GP38__PRTDSI__OE_SEL0) 
#define GP38_PRTDSI__OE_SEL1        (* (reg8 *) GP38__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define GP38_PRTDSI__OUT_SEL0       (* (reg8 *) GP38__PRTDSI__OUT_SEL0) 
#define GP38_PRTDSI__OUT_SEL1       (* (reg8 *) GP38__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define GP38_PRTDSI__SYNC_OUT       (* (reg8 *) GP38__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(GP38__SIO_CFG)
    #define GP38_SIO_HYST_EN        (* (reg8 *) GP38__SIO_HYST_EN)
    #define GP38_SIO_REG_HIFREQ     (* (reg8 *) GP38__SIO_REG_HIFREQ)
    #define GP38_SIO_CFG            (* (reg8 *) GP38__SIO_CFG)
    #define GP38_SIO_DIFF           (* (reg8 *) GP38__SIO_DIFF)
#endif /* (GP38__SIO_CFG) */

/* Interrupt Registers */
#if defined(GP38__INTSTAT)
    #define GP38_INTSTAT            (* (reg8 *) GP38__INTSTAT)
    #define GP38_SNAP               (* (reg8 *) GP38__SNAP)
    
	#define GP38_0_INTTYPE_REG 		(* (reg8 *) GP38__0__INTTYPE)
#endif /* (GP38__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_GP38_H */


/* [] END OF FILE */
