/*******************************************************************************
* File Name: GP5.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_GP5_H) /* Pins GP5_H */
#define CY_PINS_GP5_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "GP5_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 GP5__PORT == 15 && ((GP5__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    GP5_Write(uint8 value);
void    GP5_SetDriveMode(uint8 mode);
uint8   GP5_ReadDataReg(void);
uint8   GP5_Read(void);
void    GP5_SetInterruptMode(uint16 position, uint16 mode);
uint8   GP5_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the GP5_SetDriveMode() function.
     *  @{
     */
        #define GP5_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define GP5_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define GP5_DM_RES_UP          PIN_DM_RES_UP
        #define GP5_DM_RES_DWN         PIN_DM_RES_DWN
        #define GP5_DM_OD_LO           PIN_DM_OD_LO
        #define GP5_DM_OD_HI           PIN_DM_OD_HI
        #define GP5_DM_STRONG          PIN_DM_STRONG
        #define GP5_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define GP5_MASK               GP5__MASK
#define GP5_SHIFT              GP5__SHIFT
#define GP5_WIDTH              5u

/* Interrupt constants */
#if defined(GP5__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in GP5_SetInterruptMode() function.
     *  @{
     */
        #define GP5_INTR_NONE      (uint16)(0x0000u)
        #define GP5_INTR_RISING    (uint16)(0x0001u)
        #define GP5_INTR_FALLING   (uint16)(0x0002u)
        #define GP5_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define GP5_INTR_MASK      (0x01u) 
#endif /* (GP5__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define GP5_PS                     (* (reg8 *) GP5__PS)
/* Data Register */
#define GP5_DR                     (* (reg8 *) GP5__DR)
/* Port Number */
#define GP5_PRT_NUM                (* (reg8 *) GP5__PRT) 
/* Connect to Analog Globals */                                                  
#define GP5_AG                     (* (reg8 *) GP5__AG)                       
/* Analog MUX bux enable */
#define GP5_AMUX                   (* (reg8 *) GP5__AMUX) 
/* Bidirectional Enable */                                                        
#define GP5_BIE                    (* (reg8 *) GP5__BIE)
/* Bit-mask for Aliased Register Access */
#define GP5_BIT_MASK               (* (reg8 *) GP5__BIT_MASK)
/* Bypass Enable */
#define GP5_BYP                    (* (reg8 *) GP5__BYP)
/* Port wide control signals */                                                   
#define GP5_CTL                    (* (reg8 *) GP5__CTL)
/* Drive Modes */
#define GP5_DM0                    (* (reg8 *) GP5__DM0) 
#define GP5_DM1                    (* (reg8 *) GP5__DM1)
#define GP5_DM2                    (* (reg8 *) GP5__DM2) 
/* Input Buffer Disable Override */
#define GP5_INP_DIS                (* (reg8 *) GP5__INP_DIS)
/* LCD Common or Segment Drive */
#define GP5_LCD_COM_SEG            (* (reg8 *) GP5__LCD_COM_SEG)
/* Enable Segment LCD */
#define GP5_LCD_EN                 (* (reg8 *) GP5__LCD_EN)
/* Slew Rate Control */
#define GP5_SLW                    (* (reg8 *) GP5__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define GP5_PRTDSI__CAPS_SEL       (* (reg8 *) GP5__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define GP5_PRTDSI__DBL_SYNC_IN    (* (reg8 *) GP5__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define GP5_PRTDSI__OE_SEL0        (* (reg8 *) GP5__PRTDSI__OE_SEL0) 
#define GP5_PRTDSI__OE_SEL1        (* (reg8 *) GP5__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define GP5_PRTDSI__OUT_SEL0       (* (reg8 *) GP5__PRTDSI__OUT_SEL0) 
#define GP5_PRTDSI__OUT_SEL1       (* (reg8 *) GP5__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define GP5_PRTDSI__SYNC_OUT       (* (reg8 *) GP5__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(GP5__SIO_CFG)
    #define GP5_SIO_HYST_EN        (* (reg8 *) GP5__SIO_HYST_EN)
    #define GP5_SIO_REG_HIFREQ     (* (reg8 *) GP5__SIO_REG_HIFREQ)
    #define GP5_SIO_CFG            (* (reg8 *) GP5__SIO_CFG)
    #define GP5_SIO_DIFF           (* (reg8 *) GP5__SIO_DIFF)
#endif /* (GP5__SIO_CFG) */

/* Interrupt Registers */
#if defined(GP5__INTSTAT)
    #define GP5_INTSTAT            (* (reg8 *) GP5__INTSTAT)
    #define GP5_SNAP               (* (reg8 *) GP5__SNAP)
    
	#define GP5_0_INTTYPE_REG 		(* (reg8 *) GP5__0__INTTYPE)
	#define GP5_1_INTTYPE_REG 		(* (reg8 *) GP5__1__INTTYPE)
	#define GP5_2_INTTYPE_REG 		(* (reg8 *) GP5__2__INTTYPE)
	#define GP5_3_INTTYPE_REG 		(* (reg8 *) GP5__3__INTTYPE)
	#define GP5_4_INTTYPE_REG 		(* (reg8 *) GP5__4__INTTYPE)
#endif /* (GP5__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_GP5_H */


/* [] END OF FILE */
