/*******************************************************************************
* File Name: MPURR0_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "MPURR0.h"

/* Check for removal by optimization */
#if !defined(MPURR0_Sync_ctrl_reg__REMOVED)

static MPURR0_BACKUP_STRUCT  MPURR0_backup = {0u};

    
/*******************************************************************************
* Function Name: MPURR0_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void MPURR0_SaveConfig(void) 
{
    MPURR0_backup.controlState = MPURR0_Control;
}


/*******************************************************************************
* Function Name: MPURR0_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void MPURR0_RestoreConfig(void) 
{
     MPURR0_Control = MPURR0_backup.controlState;
}


/*******************************************************************************
* Function Name: MPURR0_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void MPURR0_Sleep(void) 
{
    MPURR0_SaveConfig();
}


/*******************************************************************************
* Function Name: MPURR0_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void MPURR0_Wakeup(void)  
{
    MPURR0_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
