/*******************************************************************************
* File Name: NMIcnt.h  
* Version 3.0
*
*  Description:
*   Contains the function prototypes and constants available to the counter
*   user module.
*
*   Note:
*    None
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/
    
#if !defined(CY_COUNTER_NMIcnt_H)
#define CY_COUNTER_NMIcnt_H

#include "cytypes.h"
#include "cyfitter.h"
#include "CyLib.h" /* For CyEnterCriticalSection() and CyExitCriticalSection() functions */

extern uint8 NMIcnt_initVar;

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component Counter_v3_0 requires cy_boot v3.0 or later
#endif /* (CY_ PSOC5LP) */

/* Error message for removed NMIcnt_CounterUDB_sCTRLReg_ctrlreg through optimization */
#ifdef NMIcnt_CounterUDB_sCTRLReg_ctrlreg__REMOVED
    #error Counter_v3_0 detected with a constant 0 for the enable, a \
                                constant 0 for the count or constant 1 for \
                                the reset. This will prevent the component from\
                                operating.
#endif /* NMIcnt_CounterUDB_sCTRLReg_ctrlreg__REMOVED */


/**************************************
*           Parameter Defaults        
**************************************/

#define NMIcnt_Resolution            8u
#define NMIcnt_UsingFixedFunction    0u
#define NMIcnt_ControlRegRemoved     0u
#define NMIcnt_COMPARE_MODE_SOFTWARE 0u
#define NMIcnt_CAPTURE_MODE_SOFTWARE 0u
#define NMIcnt_RunModeUsed           0u


/***************************************
*       Type defines
***************************************/


/**************************************************************************
 * Sleep Mode API Support
 * Backup structure for Sleep Wake up operations
 *************************************************************************/
typedef struct
{
    uint8 CounterEnableState; 
    uint8 CounterUdb;         /* Current Counter Value */

    #if (!NMIcnt_ControlRegRemoved)
        uint8 CounterControlRegister;               /* Counter Control Register */
    #endif /* (!NMIcnt_ControlRegRemoved) */

}NMIcnt_backupStruct;


/**************************************
 *  Function Prototypes
 *************************************/
void    NMIcnt_Start(void) ;
void    NMIcnt_Stop(void) ;
void    NMIcnt_SetInterruptMode(uint8 interruptsMask) ;
uint8   NMIcnt_ReadStatusRegister(void) ;
#define NMIcnt_GetInterruptSource() NMIcnt_ReadStatusRegister()
#if(!NMIcnt_ControlRegRemoved)
    uint8   NMIcnt_ReadControlRegister(void) ;
    void    NMIcnt_WriteControlRegister(uint8 control) \
        ;
#endif /* (!NMIcnt_ControlRegRemoved) */
#if (!(NMIcnt_UsingFixedFunction && (CY_PSOC5A)))
    void    NMIcnt_WriteCounter(uint8 counter) \
            ; 
#endif /* (!(NMIcnt_UsingFixedFunction && (CY_PSOC5A))) */
uint8  NMIcnt_ReadCounter(void) ;
uint8  NMIcnt_ReadCapture(void) ;
void    NMIcnt_WritePeriod(uint8 period) \
    ;
uint8  NMIcnt_ReadPeriod( void ) ;
#if (!NMIcnt_UsingFixedFunction)
    void    NMIcnt_WriteCompare(uint8 compare) \
        ;
    uint8  NMIcnt_ReadCompare( void ) \
        ;
#endif /* (!NMIcnt_UsingFixedFunction) */

#if (NMIcnt_COMPARE_MODE_SOFTWARE)
    void    NMIcnt_SetCompareMode(uint8 compareMode) ;
#endif /* (NMIcnt_COMPARE_MODE_SOFTWARE) */
#if (NMIcnt_CAPTURE_MODE_SOFTWARE)
    void    NMIcnt_SetCaptureMode(uint8 captureMode) ;
#endif /* (NMIcnt_CAPTURE_MODE_SOFTWARE) */
void NMIcnt_ClearFIFO(void)     ;
void NMIcnt_Init(void)          ;
void NMIcnt_Enable(void)        ;
void NMIcnt_SaveConfig(void)    ;
void NMIcnt_RestoreConfig(void) ;
void NMIcnt_Sleep(void)         ;
void NMIcnt_Wakeup(void)        ;


/***************************************
*   Enumerated Types and Parameters
***************************************/

/* Enumerated Type B_Counter__CompareModes, Used in Compare Mode retained for backward compatibility of tests*/
#define NMIcnt__B_COUNTER__LESS_THAN 1
#define NMIcnt__B_COUNTER__LESS_THAN_OR_EQUAL 2
#define NMIcnt__B_COUNTER__EQUAL 0
#define NMIcnt__B_COUNTER__GREATER_THAN 3
#define NMIcnt__B_COUNTER__GREATER_THAN_OR_EQUAL 4
#define NMIcnt__B_COUNTER__SOFTWARE 5

/* Enumerated Type Counter_CompareModes */
#define NMIcnt_CMP_MODE_LT 1u
#define NMIcnt_CMP_MODE_LTE 2u
#define NMIcnt_CMP_MODE_EQ 0u
#define NMIcnt_CMP_MODE_GT 3u
#define NMIcnt_CMP_MODE_GTE 4u
#define NMIcnt_CMP_MODE_SOFTWARE_CONTROLLED 5u

/* Enumerated Type B_Counter__CaptureModes, Used in Capture Mode retained for backward compatibility of tests*/
#define NMIcnt__B_COUNTER__NONE 0
#define NMIcnt__B_COUNTER__RISING_EDGE 1
#define NMIcnt__B_COUNTER__FALLING_EDGE 2
#define NMIcnt__B_COUNTER__EITHER_EDGE 3
#define NMIcnt__B_COUNTER__SOFTWARE_CONTROL 4

/* Enumerated Type Counter_CompareModes */
#define NMIcnt_CAP_MODE_NONE 0u
#define NMIcnt_CAP_MODE_RISE 1u
#define NMIcnt_CAP_MODE_FALL 2u
#define NMIcnt_CAP_MODE_BOTH 3u
#define NMIcnt_CAP_MODE_SOFTWARE_CONTROLLED 4u


/***************************************
 *  Initialization Values
 **************************************/
#define NMIcnt_CAPTURE_MODE_CONF       0u
#define NMIcnt_INIT_PERIOD_VALUE       207u
#define NMIcnt_INIT_COUNTER_VALUE      0u
#if (NMIcnt_UsingFixedFunction)
#define NMIcnt_INIT_INTERRUPTS_MASK    ((uint8)((uint8)0u << NMIcnt_STATUS_ZERO_INT_EN_MASK_SHIFT))
#else
#define NMIcnt_INIT_COMPARE_VALUE      192u
#define NMIcnt_INIT_INTERRUPTS_MASK ((uint8)((uint8)0u << NMIcnt_STATUS_ZERO_INT_EN_MASK_SHIFT) | \
        ((uint8)((uint8)0u << NMIcnt_STATUS_CAPTURE_INT_EN_MASK_SHIFT)) | \
        ((uint8)((uint8)0u << NMIcnt_STATUS_CMP_INT_EN_MASK_SHIFT)) | \
        ((uint8)((uint8)0u << NMIcnt_STATUS_OVERFLOW_INT_EN_MASK_SHIFT)) | \
        ((uint8)((uint8)0u << NMIcnt_STATUS_UNDERFLOW_INT_EN_MASK_SHIFT)))
#define NMIcnt_DEFAULT_COMPARE_MODE    2u

#if( 0 != NMIcnt_CAPTURE_MODE_CONF)
    #define NMIcnt_DEFAULT_CAPTURE_MODE    ((uint8)((uint8)0u << NMIcnt_CTRL_CAPMODE0_SHIFT))
#else    
    #define NMIcnt_DEFAULT_CAPTURE_MODE    (0u )
#endif /* ( 0 != NMIcnt_CAPTURE_MODE_CONF) */

#endif /* (NMIcnt_UsingFixedFunction) */


/**************************************
 *  Registers
 *************************************/
#if (NMIcnt_UsingFixedFunction)
    #define NMIcnt_STATICCOUNT_LSB     (*(reg16 *) NMIcnt_CounterHW__CAP0 )
    #define NMIcnt_STATICCOUNT_LSB_PTR ( (reg16 *) NMIcnt_CounterHW__CAP0 )
    #define NMIcnt_PERIOD_LSB          (*(reg16 *) NMIcnt_CounterHW__PER0 )
    #define NMIcnt_PERIOD_LSB_PTR      ( (reg16 *) NMIcnt_CounterHW__PER0 )
    /* MODE must be set to 1 to set the compare value */
    #define NMIcnt_COMPARE_LSB         (*(reg16 *) NMIcnt_CounterHW__CNT_CMP0 )
    #define NMIcnt_COMPARE_LSB_PTR     ( (reg16 *) NMIcnt_CounterHW__CNT_CMP0 )
    /* MODE must be set to 0 to get the count */
    #define NMIcnt_COUNTER_LSB         (*(reg16 *) NMIcnt_CounterHW__CNT_CMP0 )
    #define NMIcnt_COUNTER_LSB_PTR     ( (reg16 *) NMIcnt_CounterHW__CNT_CMP0 )
    #define NMIcnt_RT1                 (*(reg8 *) NMIcnt_CounterHW__RT1)
    #define NMIcnt_RT1_PTR             ( (reg8 *) NMIcnt_CounterHW__RT1)
#else
    
    #if (NMIcnt_Resolution <= 8u) /* 8-bit Counter */
    
        #define NMIcnt_STATICCOUNT_LSB     (*(reg8 *) \
            NMIcnt_CounterUDB_sC8_counterdp_u0__F0_REG )
        #define NMIcnt_STATICCOUNT_LSB_PTR ( (reg8 *) \
            NMIcnt_CounterUDB_sC8_counterdp_u0__F0_REG )
        #define NMIcnt_PERIOD_LSB          (*(reg8 *) \
            NMIcnt_CounterUDB_sC8_counterdp_u0__D0_REG )
        #define NMIcnt_PERIOD_LSB_PTR      ( (reg8 *) \
            NMIcnt_CounterUDB_sC8_counterdp_u0__D0_REG )
        #define NMIcnt_COMPARE_LSB         (*(reg8 *) \
            NMIcnt_CounterUDB_sC8_counterdp_u0__D1_REG )
        #define NMIcnt_COMPARE_LSB_PTR     ( (reg8 *) \
            NMIcnt_CounterUDB_sC8_counterdp_u0__D1_REG )
        #define NMIcnt_COUNTER_LSB         (*(reg8 *) \
            NMIcnt_CounterUDB_sC8_counterdp_u0__A0_REG )  
        #define NMIcnt_COUNTER_LSB_PTR     ( (reg8 *)\
            NMIcnt_CounterUDB_sC8_counterdp_u0__A0_REG )
    
    #elif(NMIcnt_Resolution <= 16u) /* 16-bit Counter */
        #if(CY_PSOC3) /* 8-bit address space */ 
            #define NMIcnt_STATICCOUNT_LSB     (*(reg16 *) \
                NMIcnt_CounterUDB_sC8_counterdp_u0__F0_REG )
            #define NMIcnt_STATICCOUNT_LSB_PTR ( (reg16 *) \
                NMIcnt_CounterUDB_sC8_counterdp_u0__F0_REG )
            #define NMIcnt_PERIOD_LSB          (*(reg16 *) \
                NMIcnt_CounterUDB_sC8_counterdp_u0__D0_REG )
            #define NMIcnt_PERIOD_LSB_PTR      ( (reg16 *) \
                NMIcnt_CounterUDB_sC8_counterdp_u0__D0_REG )
            #define NMIcnt_COMPARE_LSB         (*(reg16 *) \
                NMIcnt_CounterUDB_sC8_counterdp_u0__D1_REG )
            #define NMIcnt_COMPARE_LSB_PTR     ( (reg16 *) \
                NMIcnt_CounterUDB_sC8_counterdp_u0__D1_REG )
            #define NMIcnt_COUNTER_LSB         (*(reg16 *) \
                NMIcnt_CounterUDB_sC8_counterdp_u0__A0_REG )  
            #define NMIcnt_COUNTER_LSB_PTR     ( (reg16 *)\
                NMIcnt_CounterUDB_sC8_counterdp_u0__A0_REG )
        #else /* 16-bit address space */
            #define NMIcnt_STATICCOUNT_LSB     (*(reg16 *) \
                NMIcnt_CounterUDB_sC8_counterdp_u0__16BIT_F0_REG )
            #define NMIcnt_STATICCOUNT_LSB_PTR ( (reg16 *) \
                NMIcnt_CounterUDB_sC8_counterdp_u0__16BIT_F0_REG )
            #define NMIcnt_PERIOD_LSB          (*(reg16 *) \
                NMIcnt_CounterUDB_sC8_counterdp_u0__16BIT_D0_REG )
            #define NMIcnt_PERIOD_LSB_PTR      ( (reg16 *) \
                NMIcnt_CounterUDB_sC8_counterdp_u0__16BIT_D0_REG )
            #define NMIcnt_COMPARE_LSB         (*(reg16 *) \
                NMIcnt_CounterUDB_sC8_counterdp_u0__16BIT_D1_REG )
            #define NMIcnt_COMPARE_LSB_PTR     ( (reg16 *) \
                NMIcnt_CounterUDB_sC8_counterdp_u0__16BIT_D1_REG )
            #define NMIcnt_COUNTER_LSB         (*(reg16 *) \
                NMIcnt_CounterUDB_sC8_counterdp_u0__16BIT_A0_REG )  
            #define NMIcnt_COUNTER_LSB_PTR     ( (reg16 *)\
                NMIcnt_CounterUDB_sC8_counterdp_u0__16BIT_A0_REG )
        #endif /* CY_PSOC3 */   
    #elif(NMIcnt_Resolution <= 24u) /* 24-bit Counter */
        
        #define NMIcnt_STATICCOUNT_LSB     (*(reg32 *) \
            NMIcnt_CounterUDB_sC8_counterdp_u0__F0_REG )
        #define NMIcnt_STATICCOUNT_LSB_PTR ( (reg32 *) \
            NMIcnt_CounterUDB_sC8_counterdp_u0__F0_REG )
        #define NMIcnt_PERIOD_LSB          (*(reg32 *) \
            NMIcnt_CounterUDB_sC8_counterdp_u0__D0_REG )
        #define NMIcnt_PERIOD_LSB_PTR      ( (reg32 *) \
            NMIcnt_CounterUDB_sC8_counterdp_u0__D0_REG )
        #define NMIcnt_COMPARE_LSB         (*(reg32 *) \
            NMIcnt_CounterUDB_sC8_counterdp_u0__D1_REG )
        #define NMIcnt_COMPARE_LSB_PTR     ( (reg32 *) \
            NMIcnt_CounterUDB_sC8_counterdp_u0__D1_REG )
        #define NMIcnt_COUNTER_LSB         (*(reg32 *) \
            NMIcnt_CounterUDB_sC8_counterdp_u0__A0_REG )  
        #define NMIcnt_COUNTER_LSB_PTR     ( (reg32 *)\
            NMIcnt_CounterUDB_sC8_counterdp_u0__A0_REG )
    
    #else /* 32-bit Counter */
        #if(CY_PSOC3 || CY_PSOC5) /* 8-bit address space */
            #define NMIcnt_STATICCOUNT_LSB     (*(reg32 *) \
                NMIcnt_CounterUDB_sC8_counterdp_u0__F0_REG )
            #define NMIcnt_STATICCOUNT_LSB_PTR ( (reg32 *) \
                NMIcnt_CounterUDB_sC8_counterdp_u0__F0_REG )
            #define NMIcnt_PERIOD_LSB          (*(reg32 *) \
                NMIcnt_CounterUDB_sC8_counterdp_u0__D0_REG )
            #define NMIcnt_PERIOD_LSB_PTR      ( (reg32 *) \
                NMIcnt_CounterUDB_sC8_counterdp_u0__D0_REG )
            #define NMIcnt_COMPARE_LSB         (*(reg32 *) \
                NMIcnt_CounterUDB_sC8_counterdp_u0__D1_REG )
            #define NMIcnt_COMPARE_LSB_PTR     ( (reg32 *) \
                NMIcnt_CounterUDB_sC8_counterdp_u0__D1_REG )
            #define NMIcnt_COUNTER_LSB         (*(reg32 *) \
                NMIcnt_CounterUDB_sC8_counterdp_u0__A0_REG )  
            #define NMIcnt_COUNTER_LSB_PTR     ( (reg32 *)\
                NMIcnt_CounterUDB_sC8_counterdp_u0__A0_REG )
        #else /* 32-bit address space */
            #define NMIcnt_STATICCOUNT_LSB     (*(reg32 *) \
                NMIcnt_CounterUDB_sC8_counterdp_u0__32BIT_F0_REG )
            #define NMIcnt_STATICCOUNT_LSB_PTR ( (reg32 *) \
                NMIcnt_CounterUDB_sC8_counterdp_u0__32BIT_F0_REG )
            #define NMIcnt_PERIOD_LSB          (*(reg32 *) \
                NMIcnt_CounterUDB_sC8_counterdp_u0__32BIT_D0_REG )
            #define NMIcnt_PERIOD_LSB_PTR      ( (reg32 *) \
                NMIcnt_CounterUDB_sC8_counterdp_u0__32BIT_D0_REG )
            #define NMIcnt_COMPARE_LSB         (*(reg32 *) \
                NMIcnt_CounterUDB_sC8_counterdp_u0__32BIT_D1_REG )
            #define NMIcnt_COMPARE_LSB_PTR     ( (reg32 *) \
                NMIcnt_CounterUDB_sC8_counterdp_u0__32BIT_D1_REG )
            #define NMIcnt_COUNTER_LSB         (*(reg32 *) \
                NMIcnt_CounterUDB_sC8_counterdp_u0__32BIT_A0_REG )  
            #define NMIcnt_COUNTER_LSB_PTR     ( (reg32 *)\
                NMIcnt_CounterUDB_sC8_counterdp_u0__32BIT_A0_REG )
        #endif /* CY_PSOC3 || CY_PSOC5 */   
    #endif

	#define NMIcnt_COUNTER_LSB_PTR_8BIT     ( (reg8 *)\
                NMIcnt_CounterUDB_sC8_counterdp_u0__A0_REG )
				
    #define NMIcnt_AUX_CONTROLDP0 \
        (*(reg8 *) NMIcnt_CounterUDB_sC8_counterdp_u0__DP_AUX_CTL_REG)
    
    #define NMIcnt_AUX_CONTROLDP0_PTR \
        ( (reg8 *) NMIcnt_CounterUDB_sC8_counterdp_u0__DP_AUX_CTL_REG)
    
    #if (NMIcnt_Resolution == 16 || NMIcnt_Resolution == 24 || NMIcnt_Resolution == 32)
       #define NMIcnt_AUX_CONTROLDP1 \
           (*(reg8 *) NMIcnt_CounterUDB_sC8_counterdp_u1__DP_AUX_CTL_REG)
       #define NMIcnt_AUX_CONTROLDP1_PTR \
           ( (reg8 *) NMIcnt_CounterUDB_sC8_counterdp_u1__DP_AUX_CTL_REG)
    #endif /* (NMIcnt_Resolution == 16 || NMIcnt_Resolution == 24 || NMIcnt_Resolution == 32) */
    
    #if (NMIcnt_Resolution == 24 || NMIcnt_Resolution == 32)
       #define NMIcnt_AUX_CONTROLDP2 \
           (*(reg8 *) NMIcnt_CounterUDB_sC8_counterdp_u2__DP_AUX_CTL_REG)
       #define NMIcnt_AUX_CONTROLDP2_PTR \
           ( (reg8 *) NMIcnt_CounterUDB_sC8_counterdp_u2__DP_AUX_CTL_REG)
    #endif /* (NMIcnt_Resolution == 24 || NMIcnt_Resolution == 32) */
    
    #if (NMIcnt_Resolution == 32)
       #define NMIcnt_AUX_CONTROLDP3 \
           (*(reg8 *) NMIcnt_CounterUDB_sC8_counterdp_u3__DP_AUX_CTL_REG)
       #define NMIcnt_AUX_CONTROLDP3_PTR \
           ( (reg8 *) NMIcnt_CounterUDB_sC8_counterdp_u3__DP_AUX_CTL_REG)
    #endif /* (NMIcnt_Resolution == 32) */

#endif  /* (NMIcnt_UsingFixedFunction) */

#if (NMIcnt_UsingFixedFunction)
    #define NMIcnt_STATUS         (*(reg8 *) NMIcnt_CounterHW__SR0 )
    /* In Fixed Function Block Status and Mask are the same register */
    #define NMIcnt_STATUS_MASK             (*(reg8 *) NMIcnt_CounterHW__SR0 )
    #define NMIcnt_STATUS_MASK_PTR         ( (reg8 *) NMIcnt_CounterHW__SR0 )
    #define NMIcnt_CONTROL                 (*(reg8 *) NMIcnt_CounterHW__CFG0)
    #define NMIcnt_CONTROL_PTR             ( (reg8 *) NMIcnt_CounterHW__CFG0)
    #define NMIcnt_CONTROL2                (*(reg8 *) NMIcnt_CounterHW__CFG1)
    #define NMIcnt_CONTROL2_PTR            ( (reg8 *) NMIcnt_CounterHW__CFG1)
    #if (CY_PSOC3 || CY_PSOC5LP)
        #define NMIcnt_CONTROL3       (*(reg8 *) NMIcnt_CounterHW__CFG2)
        #define NMIcnt_CONTROL3_PTR   ( (reg8 *) NMIcnt_CounterHW__CFG2)
    #endif /* (CY_PSOC3 || CY_PSOC5LP) */
    #define NMIcnt_GLOBAL_ENABLE           (*(reg8 *) NMIcnt_CounterHW__PM_ACT_CFG)
    #define NMIcnt_GLOBAL_ENABLE_PTR       ( (reg8 *) NMIcnt_CounterHW__PM_ACT_CFG)
    #define NMIcnt_GLOBAL_STBY_ENABLE      (*(reg8 *) NMIcnt_CounterHW__PM_STBY_CFG)
    #define NMIcnt_GLOBAL_STBY_ENABLE_PTR  ( (reg8 *) NMIcnt_CounterHW__PM_STBY_CFG)
    

    /********************************
    *    Constants
    ********************************/

    /* Fixed Function Block Chosen */
    #define NMIcnt_BLOCK_EN_MASK          NMIcnt_CounterHW__PM_ACT_MSK
    #define NMIcnt_BLOCK_STBY_EN_MASK     NMIcnt_CounterHW__PM_STBY_MSK 
    
    /* Control Register Bit Locations */    
    /* As defined in Register Map, part of TMRX_CFG0 register */
    #define NMIcnt_CTRL_ENABLE_SHIFT      0x00u
    #define NMIcnt_ONESHOT_SHIFT          0x02u
    /* Control Register Bit Masks */
    #define NMIcnt_CTRL_ENABLE            ((uint8)((uint8)0x01u << NMIcnt_CTRL_ENABLE_SHIFT))         
    #define NMIcnt_ONESHOT                ((uint8)((uint8)0x01u << NMIcnt_ONESHOT_SHIFT))

    /* Control2 Register Bit Masks */
    /* Set the mask for run mode */
    #if (CY_PSOC5A)
        /* Use CFG1 Mode bits to set run mode */
        #define NMIcnt_CTRL_MODE_SHIFT        0x01u    
        #define NMIcnt_CTRL_MODE_MASK         ((uint8)((uint8)0x07u << NMIcnt_CTRL_MODE_SHIFT))
    #endif /* (CY_PSOC5A) */
    #if (CY_PSOC3 || CY_PSOC5LP)
        /* Use CFG2 Mode bits to set run mode */
        #define NMIcnt_CTRL_MODE_SHIFT        0x00u    
        #define NMIcnt_CTRL_MODE_MASK         ((uint8)((uint8)0x03u << NMIcnt_CTRL_MODE_SHIFT))
    #endif /* (CY_PSOC3 || CY_PSOC5LP) */
    /* Set the mask for interrupt (raw/status register) */
    #define NMIcnt_CTRL2_IRQ_SEL_SHIFT     0x00u
    #define NMIcnt_CTRL2_IRQ_SEL          ((uint8)((uint8)0x01u << NMIcnt_CTRL2_IRQ_SEL_SHIFT))     
    
    /* Status Register Bit Locations */
    #define NMIcnt_STATUS_ZERO_SHIFT      0x07u  /* As defined in Register Map, part of TMRX_SR0 register */ 

    /* Status Register Interrupt Enable Bit Locations */
    #define NMIcnt_STATUS_ZERO_INT_EN_MASK_SHIFT      (NMIcnt_STATUS_ZERO_SHIFT - 0x04u)

    /* Status Register Bit Masks */                           
    #define NMIcnt_STATUS_ZERO            ((uint8)((uint8)0x01u << NMIcnt_STATUS_ZERO_SHIFT))

    /* Status Register Interrupt Bit Masks*/
    #define NMIcnt_STATUS_ZERO_INT_EN_MASK       ((uint8)((uint8)NMIcnt_STATUS_ZERO >> 0x04u))
    
    /*RT1 Synch Constants: Applicable for PSoC3 and PSoC5LP */
    #define NMIcnt_RT1_SHIFT            0x04u
    #define NMIcnt_RT1_MASK             ((uint8)((uint8)0x03u << NMIcnt_RT1_SHIFT))  /* Sync TC and CMP bit masks */
    #define NMIcnt_SYNC                 ((uint8)((uint8)0x03u << NMIcnt_RT1_SHIFT))
    #define NMIcnt_SYNCDSI_SHIFT        0x00u
    #define NMIcnt_SYNCDSI_MASK         ((uint8)((uint8)0x0Fu << NMIcnt_SYNCDSI_SHIFT)) /* Sync all DSI inputs */
    #define NMIcnt_SYNCDSI_EN           ((uint8)((uint8)0x0Fu << NMIcnt_SYNCDSI_SHIFT)) /* Sync all DSI inputs */
    
#else /* !NMIcnt_UsingFixedFunction */
    #define NMIcnt_STATUS               (* (reg8 *) NMIcnt_CounterUDB_sSTSReg_stsreg__STATUS_REG )
    #define NMIcnt_STATUS_PTR           (  (reg8 *) NMIcnt_CounterUDB_sSTSReg_stsreg__STATUS_REG )
    #define NMIcnt_STATUS_MASK          (* (reg8 *) NMIcnt_CounterUDB_sSTSReg_stsreg__MASK_REG )
    #define NMIcnt_STATUS_MASK_PTR      (  (reg8 *) NMIcnt_CounterUDB_sSTSReg_stsreg__MASK_REG )
    #define NMIcnt_STATUS_AUX_CTRL      (*(reg8 *) NMIcnt_CounterUDB_sSTSReg_stsreg__STATUS_AUX_CTL_REG)
    #define NMIcnt_STATUS_AUX_CTRL_PTR  ( (reg8 *) NMIcnt_CounterUDB_sSTSReg_stsreg__STATUS_AUX_CTL_REG)
    #define NMIcnt_CONTROL              (* (reg8 *) NMIcnt_CounterUDB_sCTRLReg_ctrlreg__CONTROL_REG )
    #define NMIcnt_CONTROL_PTR          (  (reg8 *) NMIcnt_CounterUDB_sCTRLReg_ctrlreg__CONTROL_REG )


    /********************************
    *    Constants
    ********************************/
    /* Control Register Bit Locations */
    #define NMIcnt_CTRL_CAPMODE0_SHIFT    0x03u       /* As defined by Verilog Implementation */
    #define NMIcnt_CTRL_RESET_SHIFT       0x06u       /* As defined by Verilog Implementation */
    #define NMIcnt_CTRL_ENABLE_SHIFT      0x07u       /* As defined by Verilog Implementation */
    /* Control Register Bit Masks */
    #define NMIcnt_CTRL_CMPMODE_MASK      0x07u 
    #define NMIcnt_CTRL_CAPMODE_MASK      0x03u  
    #define NMIcnt_CTRL_RESET             ((uint8)((uint8)0x01u << NMIcnt_CTRL_RESET_SHIFT))  
    #define NMIcnt_CTRL_ENABLE            ((uint8)((uint8)0x01u << NMIcnt_CTRL_ENABLE_SHIFT)) 

    /* Status Register Bit Locations */
    #define NMIcnt_STATUS_CMP_SHIFT       0x00u       /* As defined by Verilog Implementation */
    #define NMIcnt_STATUS_ZERO_SHIFT      0x01u       /* As defined by Verilog Implementation */
    #define NMIcnt_STATUS_OVERFLOW_SHIFT  0x02u       /* As defined by Verilog Implementation */
    #define NMIcnt_STATUS_UNDERFLOW_SHIFT 0x03u       /* As defined by Verilog Implementation */
    #define NMIcnt_STATUS_CAPTURE_SHIFT   0x04u       /* As defined by Verilog Implementation */
    #define NMIcnt_STATUS_FIFOFULL_SHIFT  0x05u       /* As defined by Verilog Implementation */
    #define NMIcnt_STATUS_FIFONEMP_SHIFT  0x06u       /* As defined by Verilog Implementation */
    /* Status Register Interrupt Enable Bit Locations - UDB Status Interrupt Mask match Status Bit Locations*/
    #define NMIcnt_STATUS_CMP_INT_EN_MASK_SHIFT       NMIcnt_STATUS_CMP_SHIFT       
    #define NMIcnt_STATUS_ZERO_INT_EN_MASK_SHIFT      NMIcnt_STATUS_ZERO_SHIFT      
    #define NMIcnt_STATUS_OVERFLOW_INT_EN_MASK_SHIFT  NMIcnt_STATUS_OVERFLOW_SHIFT  
    #define NMIcnt_STATUS_UNDERFLOW_INT_EN_MASK_SHIFT NMIcnt_STATUS_UNDERFLOW_SHIFT 
    #define NMIcnt_STATUS_CAPTURE_INT_EN_MASK_SHIFT   NMIcnt_STATUS_CAPTURE_SHIFT   
    #define NMIcnt_STATUS_FIFOFULL_INT_EN_MASK_SHIFT  NMIcnt_STATUS_FIFOFULL_SHIFT  
    #define NMIcnt_STATUS_FIFONEMP_INT_EN_MASK_SHIFT  NMIcnt_STATUS_FIFONEMP_SHIFT  
    /* Status Register Bit Masks */                
    #define NMIcnt_STATUS_CMP             ((uint8)((uint8)0x01u << NMIcnt_STATUS_CMP_SHIFT))  
    #define NMIcnt_STATUS_ZERO            ((uint8)((uint8)0x01u << NMIcnt_STATUS_ZERO_SHIFT)) 
    #define NMIcnt_STATUS_OVERFLOW        ((uint8)((uint8)0x01u << NMIcnt_STATUS_OVERFLOW_SHIFT)) 
    #define NMIcnt_STATUS_UNDERFLOW       ((uint8)((uint8)0x01u << NMIcnt_STATUS_UNDERFLOW_SHIFT)) 
    #define NMIcnt_STATUS_CAPTURE         ((uint8)((uint8)0x01u << NMIcnt_STATUS_CAPTURE_SHIFT)) 
    #define NMIcnt_STATUS_FIFOFULL        ((uint8)((uint8)0x01u << NMIcnt_STATUS_FIFOFULL_SHIFT))
    #define NMIcnt_STATUS_FIFONEMP        ((uint8)((uint8)0x01u << NMIcnt_STATUS_FIFONEMP_SHIFT))
    /* Status Register Interrupt Bit Masks  - UDB Status Interrupt Mask match Status Bit Locations */
    #define NMIcnt_STATUS_CMP_INT_EN_MASK            NMIcnt_STATUS_CMP                    
    #define NMIcnt_STATUS_ZERO_INT_EN_MASK           NMIcnt_STATUS_ZERO            
    #define NMIcnt_STATUS_OVERFLOW_INT_EN_MASK       NMIcnt_STATUS_OVERFLOW        
    #define NMIcnt_STATUS_UNDERFLOW_INT_EN_MASK      NMIcnt_STATUS_UNDERFLOW       
    #define NMIcnt_STATUS_CAPTURE_INT_EN_MASK        NMIcnt_STATUS_CAPTURE         
    #define NMIcnt_STATUS_FIFOFULL_INT_EN_MASK       NMIcnt_STATUS_FIFOFULL        
    #define NMIcnt_STATUS_FIFONEMP_INT_EN_MASK       NMIcnt_STATUS_FIFONEMP         
    

    /* StatusI Interrupt Enable bit Location in the Auxilliary Control Register */
    #define NMIcnt_STATUS_ACTL_INT_EN     0x10u /* As defined for the ACTL Register */
    
    /* Datapath Auxillary Control Register definitions */
    #define NMIcnt_AUX_CTRL_FIFO0_CLR         0x01u   /* As defined by Register map */
    #define NMIcnt_AUX_CTRL_FIFO1_CLR         0x02u   /* As defined by Register map */
    #define NMIcnt_AUX_CTRL_FIFO0_LVL         0x04u   /* As defined by Register map */
    #define NMIcnt_AUX_CTRL_FIFO1_LVL         0x08u   /* As defined by Register map */
    #define NMIcnt_STATUS_ACTL_INT_EN_MASK    0x10u   /* As defined for the ACTL Register */
    
#endif /* NMIcnt_UsingFixedFunction */

#endif  /* CY_COUNTER_NMIcnt_H */


/* [] END OF FILE */

