/*******************************************************************************
* File Name: zx81reg_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "zx81reg.h"

/* Check for removal by optimization */
#if !defined(zx81reg_Sync_ctrl_reg__REMOVED)

static zx81reg_BACKUP_STRUCT  zx81reg_backup = {0u};

    
/*******************************************************************************
* Function Name: zx81reg_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void zx81reg_SaveConfig(void) 
{
    zx81reg_backup.controlState = zx81reg_Control;
}


/*******************************************************************************
* Function Name: zx81reg_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void zx81reg_RestoreConfig(void) 
{
     zx81reg_Control = zx81reg_backup.controlState;
}


/*******************************************************************************
* Function Name: zx81reg_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void zx81reg_Sleep(void) 
{
    zx81reg_SaveConfig();
}


/*******************************************************************************
* Function Name: zx81reg_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void zx81reg_Wakeup(void)  
{
    zx81reg_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
