#include "project.h"
#include "common.h"

/* A[15..8] -> Ah -> P6 */
/* A[ 7..0] -> Al -> P2 */
/* D[ 7..0] -> D  -> P4 */
/* OE/CE/WE -> x  -> P0[5/6/7] */
/* TODO : Banks    -> x  -> P1[2..6] */

uint8 ports[]={0,1,2,4,6};
uint8 port_config[5][7]; /* PRT0-PRT1-PRT2-PRT4-PRT6 offset between ports 0x10 */

void modify_port_config(uint8 debug)
{
    uint8 i,j;
    
    /* Save Port Configs (DSI driven)*/
    for(i=0;i<5;i++)
    {
        port_config[i][0]=*(uint8*)(CYREG_PRT0_DR +0x10*ports[i]);
        port_config[i][1]=*(uint8*)(CYREG_PRT0_PS +0x10*ports[i]);
        port_config[i][2]=*(uint8*)(CYREG_PRT0_DM0+0x10*ports[i]);
        port_config[i][3]=*(uint8*)(CYREG_PRT0_DM1+0x10*ports[i]);
        port_config[i][4]=*(uint8*)(CYREG_PRT0_DM2+0x10*ports[i]);
        port_config[i][5]=*(uint8*)(CYREG_PRT0_BYP+0x10*ports[i]);
        port_config[i][6]=*(uint8*)(CYREG_PRT0_BIE+0x10*ports[i]);
    }

    if (debug)
    {
      for(i=0;i<5;i++)
      {
        uprintf("PORT ");uprinth(ports[i]);uprintf(" :\n\r");
        for(j=0;j<7;j++)
        {
            uprinth(port_config[i][j]);
            uprintf(" ");
        }
        uprintf("\n\r");
      }
    }
    
    /* Ah,Al,D, WE/CE/OE as output */

    *(uint8*)CYREG_PRT6_DM0=0;
    *(uint8*)CYREG_PRT6_DM1=0xFF;
    *(uint8*)CYREG_PRT6_DM2=0xFF;

    *(uint8*)CYREG_PRT2_DM0=0;
    *(uint8*)CYREG_PRT2_DM1=0xFF;
    *(uint8*)CYREG_PRT2_DM2=0xFF;

    *(uint8*)CYREG_PRT4_DM0=0;
    *(uint8*)CYREG_PRT4_DM1=0xFF;
    *(uint8*)CYREG_PRT4_DM2=0xFF;
    
    *(uint8*)CYREG_PRT4_BYP=0;      /* D driven by DR */   
    *(uint8*)CYREG_PRT4_BIE=0;      /* Disable OE Control */   
    *(uint8*)CYREG_PRT0_BYP&=0x1F;  /* OE/CE/WE driven by DR */
    *(uint8*)CYREG_PRT1_BYP&=0x83;  /* Banks driven by DR */
}

void restore_port_config(void)
{
    uint8 i;       
    /* Restore Port Configs */
    for(i=0;i<5;i++)
    {
        *(uint8*)(CYREG_PRT0_BIE+0x10*ports[i])=port_config[i][6];
        *(uint8*)(CYREG_PRT0_DM0+0x10*ports[i])=port_config[i][2];
        *(uint8*)(CYREG_PRT0_DM1+0x10*ports[i])=port_config[i][3];
        *(uint8*)(CYREG_PRT0_DM2+0x10*ports[i])=port_config[i][4];
        *(uint8*)(CYREG_PRT0_BYP+0x10*ports[i])=port_config[i][5];
        *(uint8*)(CYREG_PRT0_DR +0x10*ports[i])=port_config[i][0];
    }    
}

void sram_test(void)
{
    uint32 i;
    uint8 d,err,bnk;
    
    uprintf("SRAM Test\n\r");

    modify_port_config(1);
    
    CEn_Write(0);
    
    /* Write MEM */
    uprintf("- Writing\n\r");
    
    bnk=port_config[1][1]&0x83;

    #define verif(i) (0xAA^(i&0xFF)^((i>>8)&0xFF)^(i>>12))
    
    i=0;
    do {
        Ah_DR=(i&0x3F00)>>8; Al_DR=i&0xFF; Bank_DR=bnk|((i>>12)&0x7C);
        D_DR=verif(i);
        WEn_Write(0);
        WEn_Write(1);
        if ((i&0x3FFF)==0x3FFF) uprintf(".");
        i++;
    } while (i!=0x80000);
    uprintf("\n\r- OK\n\r");
    
    /* D as input */
    
    *(uint8*)CYREG_PRT4_DM0=0xFF;
    *(uint8*)CYREG_PRT4_DM1=0;
    *(uint8*)CYREG_PRT4_DM2=0;
    
    /* Read&Verify */
    uprintf("- Reading\n\r");

    i=0;err=0;
    do {
        Ah_DR=(i&0x3F00)>>8; Al_DR=i&0xFF; Bank_DR=bnk|((i>>12)&0x7C);
        OEn_Write(0);
        d=D_PS;
        OEn_Write(1);
        if (d!=verif(i))
            {uprintf("- Verify error : ");uprinth(i>>12);uprinth(i>>8);uprinth(i&0xFF);
             uprintf(" ");uprinth(d);uprintf("!=");uprinth(verif(i));uprintf("\n\r");err=1;}
        i++;
    } while ((i!=0x80000)&&(err==0));
    if (err==0) uprintf("- OK\n\r");

    CEn_Write(1);

    restore_port_config();
}

void sram_zero(void)
{
    uint32 i;
    uint8 bnk;
    
    uprintf("Zeroing SRAM\n\r");

    modify_port_config(0);
        
    CEn_Write(0);
    
    bnk=port_config[1][1]&0x83;
    
    /* Write MEM */
    uprintf("- Writing Zeros\n\r");
    
    i=0;
    do {
        Ah_DR=(i&0x3f00)>>8; Al_DR=i&0xFF; Bank_DR=bnk|((i>>12)&0x7C);
        D_DR=0;
        WEn_Write(0);
        WEn_Write(1);
        if ((i&0x3FFF)==0x3FFF) uprintf(".");
        i++;
    } while (i!=0x80000);
    uprintf("\n\r- OK\n\r");

    CEn_Write(1);
    
    restore_port_config();
}

void sram_sendfile(void)
{
    uint16 i,j;
    
    uprintf("File->RAM\n\r");

    modify_port_config(0);        
    
    Bank_DR=port_config[1][1]&0x83; /* Bank 0 - only 0x0000 to 0x3FFF */
    
    resultF=f_open(&fileO,SBC.sbc_bootfile,FA_READ);rdbytes=0;
    
    if (resultF == RES_OK) { print("ROM file \"");print(SBC.sbc_bootfile);print("\" opened\n\r");
      if (SBC.f_offset) f_lseek(&fileO,SBC.f_offset);
      resultF=f_read(&fileO,rw_buf,512,&rdbytes);      
      //if (resultF == RES_OK) { print("ROM read"); status("bytes ",rdbytes); }
    }
    
    if (rdbytes>0)
    {
    CEn_Write(0);
    
    /* Write MEM */
    uprintf("- Writing\n\r");
    //lstatus("Load ",SBC.loadaddr);
    //lstatus("Size ",SBC.f_size);
    
    i=0;
    j=0;
    do {
        Ah_DR=(i&0x3f00)>>8; Al_DR=i&0xFF; Bank_DR=(port_config[1][1]&0x83)|((i>>12)&0x7C);
        if (i<SBC.loadaddr) {if (i==0) D_DR=0xc3;
                             else if (i==1) D_DR=SBC.loadaddr&0xFF;
                             else if (i==2) D_DR=SBC.loadaddr>>8;
                             else D_DR=0;
                            }
                    else    D_DR=rw_buf[j++];
        WEn_Write(0);
        WEn_Write(1);
        if ((i&0xFFF)==0xFFF) uprintf(".");
        i++;
        if (j==rdbytes) {
            resultF=f_read(&fileO,rw_buf,512,&rdbytes);j=0;      
            //if (resultF == RES_OK) { print("ROM read"); status("bytes ",rdbytes); }
        }
        if (SBC.f_size && (i>=SBC.f_size)) break;
    } while (rdbytes!=0);
    uprintf("\n\r- OK\n\r");

    CEn_Write(1);
    }

    restore_port_config();
}

void sram_read(void)
{
    uint32 i;
    uint8 d,err,bnk;

    uprintf("SRAM Read\n\r");

    modify_port_config(1);
    
    CEn_Write(0);
    
    bnk=port_config[1][1]&0x83;

    /* D as input */
    
    *(uint8*)CYREG_PRT4_DM0=0xFF;
    *(uint8*)CYREG_PRT4_DM1=0;
    *(uint8*)CYREG_PRT4_DM2=0;
    
    i=0;err=0;
    do {
        Ah_DR=(i&0x3F00)>>8; Al_DR=i&0xFF; Bank_DR=bnk|((i>>12)&0x7C);
        OEn_Write(0);
        d=D_PS;
        OEn_Write(1);
        if ((i&15)==0) { uprintf("\n\r"); uprinth(i>>16); uprinth(i>>8); uprinth(i); uprintf(" "); }
        uprinth(d);
        i++;
    } while ((i!=0x80000)&&(err==0));
    if (err==0) uprintf("- OK\n\r");

    CEn_Write(1);

    restore_port_config();
}

